[Bioperl-guts-l] bioperl commit

Jason Stajich jason at pub.open-bio.org
Tue May 11 21:14:17 EDT 2004


jason
Tue May 11 21:14:17 EDT 2004
Update of /home/repository/bioperl/bioperl-live/Bio/PopGen/IO
In directory pub.open-bio.org:/tmp/cvs-serv24891/Bio/PopGen/IO

Modified Files:
	hapmap.pm phase.pm 
Log Message:
update Rich's email address

bioperl-live/Bio/PopGen/IO hapmap.pm,1.1,1.2 phase.pm,1.1,1.2
===================================================================
RCS file: /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/hapmap.pm,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/hapmap.pm	2004/05/10 21:49:08	1.1
+++ /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/hapmap.pm	2004/05/12 01:14:17	1.2
@@ -2,9 +2,9 @@
 #
 # BioPerl module for Bio::PopGen::IO::hapmap
 #
 # Cared for by Rich  <dobbo at thevillas.eclipse.co.uk>
 #
-# Copyright Rich 
+# Copyright Rich Dobson
 #
 # You may distribute this module under the same terms as perl itself
 
@@ -31,7 +31,7 @@
 
 =head1 DESCRIPTION
 
-Describe the object here
+A driver module for Bio::PopGen::IO for parsing hapmap data.
 
 =head1 FEEDBACK
 
@@ -52,9 +52,9 @@
 
   http://bugzilla.bioperl.org/
 
-=head1 AUTHOR - Rich 
+=head1 AUTHOR - Rich Dobson
 
-Email dobbo at thevillas.eclipse.co.uk
+Email r.j.dobson-at-qmul.ac.uk
 
 =head1 CONTRIBUTORS
 
@@ -2,9 +2,9 @@
 # BioPerl module for Bio::PopGen::IO::hapmap
 #
-# Cared for by Rich  <dobbo at thevillas.eclipse.co.uk>
+# Cared for by Rich Dobson <dobbo-at-qmul.ac.uk>
 #

===================================================================
RCS file: /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/phase.pm,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/phase.pm	2004/05/10 21:49:08	1.1
+++ /home/repository/bioperl/bioperl-live/Bio/PopGen/IO/phase.pm	2004/05/12 01:14:17	1.2
@@ -2,9 +2,9 @@
 #
 # BioPerl module for Bio::PopGen::IO::phase
 #
 # Cared for by Rich <dobbo at thevillas.eclipse.co.uk>
 #
-# Copyright Rich
+# Copyright Rich Dobson
 #
 # You may distribute this module under the same terms as perl itself
 
@@ -32,7 +32,7 @@
 
 =head1 DESCRIPTION
 
-Describe the object here
+A driver module for Bio::PopGen::IO for parsing hapmap data.
 
 =head1 FEEDBACK
 
@@ -53,9 +53,9 @@
 
   http://bugzilla.bioperl.org/
 
-=head1 AUTHOR - Rich
+=head1 AUTHOR - Rich Dobson
 
-Email dobbo at thevillas.eclipse.co.uk
+Email r.j.dobson-at-qmul.ac.uk
 
 =head1 CONTRIBUTORS
 
@@ -2,9 +2,9 @@
 # BioPerl module for Bio::PopGen::IO::phase
 #
-# Cared for by Rich <dobbo at thevillas.eclipse.co.uk>
+# Cared for by Rich <dobbo-at-qmul.ac.uk>
 #



More information about the Bioperl-guts-l mailing list